#' @title test data (pc_otu class) for pc_tax package.
#' @description an otutab, metadata and a taxonomy table.
#'
#' @docType data
#' @name pc_tax1
#' @format a pc_otu contains an otutab, metadata and a taxonomy table.
#' \describe{
#' \item{tbls}{contians otutable rawdata}
#' \item{metas}{contians metadata}
#' \item{otus}{contians taxomomy table}
#' }
NULL

#' @title all element cycle information.
#' @description all element cycle information.
#'
#' @docType data
#' @name all_ec_info
#' @format a list contains four tables.
#' \describe{
#' \item{ec_node}{chemicals}
#' \item{ec_link}{reactions}
#' \item{ec_gene}{genes}
#' \item{ec_path}{reactions labels}
#' }
NULL

#' @title all species latin names and chinese names
#' @description all species latin names and chinese names.
#'
#' @docType data
#' @name all_sp_la_zh_name
#' @format a dataframe.
#' \describe{
#' \item{latin_name}{latin name}
#' \item{chinese_name}{chinese name}
#' }
NULL
